Module: River::Driver

Defined in:
lib/driver.rb

Overview

Contains an interface used by the top-level River module to interface with its driver implementations. All types and methods in this module should be considered to be for internal use only and subject to change. API stability is not guaranteed.

Defined Under Namespace

Classes: JobInsertParams